from distutils.core import setup
setup(
  name = 'memestatus',
  packages = ['memestatus'], # this must be the same as the name above
  version = '1.0',
  description = 'A library for parsing status.memework.org',
  author = 'S Stewart',
  author_email = 'iamtheworst@programmer.net',
  url = 'https://git.memework.org/lold/memestatus', # use the URL to the github repo
  download_url = 'https://git.memework.org/lold/memestatus/archive/1.0.tar.gz', # I'll explain this in a second
  keywords = ['forfun', 'memework', 'parsing'], # arbitrary keywords
  classifiers = [],
)
